@@ -1,12 +1,12 @@
-use crate::traits::ModelAble;
+use crate::traits::ArelAble;
 use std::marker::PhantomData;
 
 #[derive(Clone, Debug)]
-pub struct Source<T: ModelAble> {
+pub struct Source<T: ArelAble> {
     _marker: PhantomData<T>
 }
 
-impl<T> Source<T> where T: ModelAble {
+impl<T> Source<T> where T: ArelAble {
     pub fn new() -> Self {
         Self {
             _marker: PhantomData,
